@@ -21,6 +21,13 @@ def printandresult(command, print_msg=True):
         lines.append(line)
     return ','.join(lines)
 
+def printandresult_shell(shell):
+    import subprocess
+    cmd = subprocess.Popen(shell, stdin=subprocess.PIPE, stderr=sys.stderr, close_fds=True,
+                           stdout=sys.stdout, universal_newlines=True, shell=True, bufsize=1)
+
+    cmd.communicate()
+    return cmd.returncode
 class logitem:
     def failitem(self,content,bold=False):
         boldstr = "1" if bold else "0"
